@@ -1263,3 +1263,17 @@ class EMailParserExec(FOFBase):
     id = Column(Integer, primary_key=True, autoincrement=True)  # parser ID
     manager_id = Column(CHAR(32), unique=True)  # 管理端ID
     p_priority_info = Column(TEXT, nullable=False)                   # parser 优先级信息 JSON 格式
+
+
+class HedgeFundEmailRaw(FOFBase):
+    '''私募基金(净值)邮件原始数据'''
+
+    __tablename__ = 'hedge_fund_email_raw'
+
+    manager_id = Column(CHAR(32), primary_key=True)  # 管理端ID
+    fof_id = Column(CHAR(16), primary_key=True)  # FOF ID
+    fund_id = Column(CHAR(16), primary_key=True)  # 基金ID
+    datetime = Column(DATE, primary_key=True)  # 日期
+    nav = Column(DOUBLE(asdecimal=False))  # 单位净值
+    acc_net_value = Column(DOUBLE(asdecimal=False))  # 累计净值
+    v_nav = Column(DOUBLE(asdecimal=False))  # 单位净值的虚拟后净值
