@@ -177,6 +177,69 @@ class FundDailyCollection(Base):
     fund_size_type = Column(CHAR(20)) # 基金规模类型
     fund_style_type = Column(CHAR(20)) # 基金风格类型
 
+    # new
+    fund_type_1 = Column(CHAR(64))  # 一级策略
+    fund_type_2 = Column(CHAR(64))  # 二级策略
+    nav_start_date = Column(DATE) # 开始时间
+    nav_end_date = Column(DATE) # 截止时间
+    nav_date = Column(CHAR(40)) # 净值日期
+    fund_nav_completion = Column(DOUBLE(asdecimal=False))  # 净值完整度
+    recent_3m_ret_annual = Column(DOUBLE(asdecimal=False))  # 近3月年化
+    recent_6m_ret_annual = Column(DOUBLE(asdecimal=False))  # 近6月年年化
+    this_y_ret_annual = Column(DOUBLE(asdecimal=False))  # 今年年化
+    recent_2y_ret_annual = Column(DOUBLE(asdecimal=False))  # 近2年年化
+    recent_2y_ret = Column(DOUBLE(asdecimal=False))  # 近1年以来收益
+    this_y_mdd = Column(DOUBLE(asdecimal=False))   # 近年以来最大回撤
+    recent_3m_mdd = Column(DOUBLE(asdecimal=False))  # 近三个月最大回撤
+    recent_6m_mdd = Column(DOUBLE(asdecimal=False))  # 近六个月最大回撤
+    recent_1y_mdd = Column(DOUBLE(asdecimal=False))  # 近一年最大回撤
+    recent_2y_mdd = Column(DOUBLE(asdecimal=False))  # 近二年最大回撤
+    calmar = Column(DOUBLE(asdecimal=False))  # 卡玛比率
+    sortino = Column(DOUBLE(asdecimal=False))  # 索提诺
+
+    @staticmethod
+    def mul_fund_view_to_private_fund_view():
+        return {'fund_id': 'fund_id',
+                'full_name': 'desc_name',
+                'nav_start_date':'start_date',
+                'nav_end_date':'end_date',
+                'nav_date':'nav_date',
+                'exchange_status':'status',
+                'fund_type_1':'fund_type_1',
+                'fund_type_2':'fund_type_2',
+                'company_name':'company',
+                'fund_manager':'manager',
+                'fund_nav_completion':'fund_nav_completion',
+                'unit_net_value':'unit_net_value',
+
+                'to_date_return': 'history_ret',
+                'annualized_returns': 'history_ret_annual',
+                'recent_3m_ret_annual':'recent_3m_ret_annual',
+                'recent_6m_ret_annual':'recent_6m_ret_annual',
+                'this_y_ret_annual':'this_y_ret_annual',
+                'recent_2y_ret_annual':'recent_2y_ret_annual',
+                'year_to_date_return': 'this_y_ret',
+                'last_three_month_return': 'recent_3m_ret',
+                'last_six_month_return': 'recent_6m_ret',
+                'last_twelve_month_return': 'recent_1y_ret',
+                'recent_2y_ret':'recent_2y_ret',
+
+                'annualized_risk':'history_vol',
+                'max_drop_down': 'history_mdd',
+                'this_y_mdd':'this_y_mdd',
+                'recent_3m_mdd':'recent_3m_mdd',
+                'recent_6m_mdd':'recent_6m_mdd',
+                'recent_1y_mdd':'recent_1y_mdd',
+                'recent_2y_mdd':'recent_2y_mdd',
+
+                'sharp_ratio': 'sharpe',
+                'var': 'var',
+                'calmar':'calmar',
+                'sortino':'sortino',
+                'var':'var',
+                }
+
+
     @staticmethod
     def trans_columns():
         return {
@@ -301,9 +364,9 @@ class FundDailyCollection(Base):
             'sector_name': '板块名字列表',
             'index_list': '指数列表',
             'index_name': '指数名字列表',
-            'top_mng_id': '头名基金经理ID',#
-            'top_mng_name': '头名基金经理名字',#
-            'top_manager_profit':'头名基金经理任期收益',#
+            'top_mng_id': '头名基金经理ID',
+            'top_mng_name': '头名基金经理名字',
+            'top_manager_profit':'头名基金经理任期收益',
             'is_abs_ret_fund': '是否是绝对收益基金',
             'is_conv_bond_fund': '是否是可转债基金',
             'is_ipo_fund': '是否是打新基金',
@@ -321,6 +384,25 @@ class FundDailyCollection(Base):
             'purchase_fee_detail':'申购费率详情',
             'redeem_fee_detail':'赎回费率详情',
             'service_fee':'销售服务费率',
+            
+            'fund_type_1':'一级策略',
+            'fund_type_2':'二级策略',
+            'nav_start_date':'开始时间',
+            'nav_end_date':'截止时间',
+            'nav_date':'净值日期',
+            'fund_nav_completion':'净值完整度',
+            'recent_3m_ret_annual':'近3月年化',
+            'recent_6m_ret_annual':'近6月年年化',
+            'this_y_ret_annual':'今年年化',
+            'recent_2y_ret_annual ':'近2年年化',
+            'recent_2y_ret':'近1年以来收益',
+            'this_y_mdd':'近年以来最大回撤',
+            'recent_3m_mdd':'近三个月最大回撤',
+            'recent_6m_mdd':'近六个月最大回撤',
+            'recent_1y_mdd':'近一年最大回撤',
+            'recent_2y_mdd':'近二年最大回撤',
+            'calmar':'卡玛比率',
+            'sortino':'索提诺',
         }
 
 
@@ -783,9 +865,17 @@ class PFFundDailyCollection(Base):
 
     fund_id = Column(CHAR(20), primary_key=True)  # 基金ID
     desc_name = Column(CHAR(40)) # 基金名
-    datetime = Column(DATE) # 时间
+    start_date = Column(DATE) # 开始时间
+    end_date = Column(DATE) # 截止时间
+    nav_date = Column(CHAR(40)) # 净值日期
+    status = Column(CHAR(40)) # 运行状态
     fund_type_1 = Column(CHAR(40)) # 一级策略
     fund_type_2 = Column(CHAR(40)) # 二级策略
+    company = Column(CHAR(80)) # 投资顾问
+    manager = Column(CHAR(80)) # 基金经理
+    fund_nav_completion = Column(DOUBLE(asdecimal=False))  # 净值完整度
+    unit_net_value = Column(DOUBLE(asdecimal=False))  # 单位净值
+
     # 收益
     history_ret = Column(DOUBLE(asdecimal=False))  # 成立以来收益
     history_ret_annual = Column(DOUBLE(asdecimal=False))  # 成立以来年化
@@ -797,33 +887,44 @@ class PFFundDailyCollection(Base):
     recent_3m_ret = Column(DOUBLE(asdecimal=False))  # 近3月年以来收益    
     recent_6m_ret = Column(DOUBLE(asdecimal=False))  # 近6月以来收益
     recent_1y_ret = Column(DOUBLE(asdecimal=False))  # 近1年以来收益    
-    recent_2y_ret = Column(DOUBLE(asdecimal=False))  # 近1年以来收益
+    recent_2y_ret = Column(DOUBLE(asdecimal=False))  # 近2年以来收益
+    
     # 风险
-    history_vol = Column(DOUBLE(asdecimal=False))  # 成立以来收益
-    history_mdd = Column(DOUBLE(asdecimal=False))  # 成立以来最大收益
+    history_vol = Column(DOUBLE(asdecimal=False))  # 成立以来波动
+    history_mdd = Column(DOUBLE(asdecimal=False))  # 成立以来最大回撤
     this_y_mdd = Column(DOUBLE(asdecimal=False))   # 近年以来最大回撤
     recent_3m_mdd = Column(DOUBLE(asdecimal=False))  # 近三个月最大回撤
     recent_6m_mdd = Column(DOUBLE(asdecimal=False))  # 近六个月最大回撤
     recent_1y_mdd = Column(DOUBLE(asdecimal=False))  # 近一年最大回撤
     recent_2y_mdd = Column(DOUBLE(asdecimal=False))  # 近二年最大回撤
+    
     # 综合
     sharpe = Column(DOUBLE(asdecimal=False))  # 夏普
     calmar = Column(DOUBLE(asdecimal=False))  # 卡玛比率
     sortino = Column(DOUBLE(asdecimal=False))  # 索提诺
     var = Column(DOUBLE(asdecimal=False))  # VaR
     
+
     @staticmethod
     def trans_columns():
         return {
             'fund_id':'基金ID',
             'desc_name':'基金名',
-            'datetime':'时间',
+            'start_date':'开始时间',
+            'end_date':'截止时间',
+            'nav_date':'净值日期',
+            'status':'运行状态',
             'fund_type_1':'一级策略',
             'fund_type_2':'二级策略',
+            'company':'投资顾问',
+            'manager':'基金经理',
+            'fund_nav_completion':'净值完整度',
+            'unit_net_value':'单位净值',
+
             'history_ret':'成立以来收益',
             'history_ret_annual':'成立以来年化',
             'recent_3m_ret_annual':'近3月年化',
-            'recent_6m_ret_annual':'抗风险能力',
+            'recent_6m_ret_annual':'近6月年化',
             'this_y_ret_annual':'今年年化',
             'recent_2y_ret_annual':'近2年年化',
             'this_y_ret':'今年以来收益',
@@ -831,13 +932,15 @@ class PFFundDailyCollection(Base):
             'recent_6m_ret':'近6月以来收益',
             'recent_1y_ret':'近1年以来收益',
             'recent_2y_ret':'近1年以来收益',
-            'history_vol':'成立以来收益',
-            'history_mdd':'成立以来最大收益',
+            
+            'history_vol':'成立以来波动',
+            'history_mdd':'成立以来最大回撤',
             'this_y_mdd':'近年以来最大回撤',
             'recent_3m_mdd':'近三个月最大回撤',
             'recent_6m_mdd':'近六个月最大回撤',
             'recent_1y_mdd':'近一年最大回撤',
             'recent_2y_mdd':'近二年最大回撤',
+            
             'sharpe':'夏普',
             'calmar':'卡玛比率',
             'sortino':'索提诺',
