@@ -327,13 +327,14 @@ class FundTrader(AssetTrader):
         _fund_rebalance_min_name = ''
         fund_rank_list = []
         cur_asset_mv = AssetValue(prices=cur_asset_price, positions=cur_asset_position)
-        cur_asset_weight = cur_asset_mv.get_weight()
+        #cur_asset_weight = cur_asset_mv.get_weight()
+        cur_asset_weight = cur_fund_position.calc_index_weight_by_fund_pos(fund_navs=cur_fund_nav).__dict__
         for index_id, index_tar_wgt in tar_asset_weight.__dict__.items():
             if index_id == 'cash':
                 continue
             c = AssetTradeCache(index_id=index_id)
             c.index_tar_wgt = index_tar_wgt
-            c.index_cur_wgt = cur_asset_weight.__dict__[index_id]
+            c.index_cur_wgt = cur_asset_weight[index_id]
             c.index_diff = c.index_tar_wgt - c.index_cur_wgt
             if abs(c.index_diff) > index_rebalance_max_diff:
                 index_rebalance_max_diff = abs(c.index_diff)
@@ -385,7 +386,7 @@ class FundTrader(AssetTrader):
             
             if index_tar_wgt > self.fund_param.DiffJudgeAssetWgtRequirement:
                 if index_id != 'mmf':
-                    if fund_selection_min_score > c.fund_judge_ranking:
+                    if fund_selection_min_score >= c.fund_judge_ranking:
                         fund_selection_min_score = c.fund_judge_ranking
                         _fund_selection_min_name = index_id
                         fund_rank_list = _rank_list
@@ -393,8 +394,8 @@ class FundTrader(AssetTrader):
                 if fund_rebalance_min_score > c.fund_judge_diverse:
                     fund_rebalance_min_score = c.fund_judge_diverse
                     _fund_rebalance_min_name = index_id
+                #print(f'{dt} dt c.cur_fund_ids {c.cur_fund_ids} index_id {index_id} fund_rank_list {fund_rank_list} _rank_list {_rank_list} index_tar_wgt {index_tar_wgt} DiffJudgeAssetWgtRequirement {self.fund_param.DiffJudgeAssetWgtRequirement} con {index_tar_wgt > self.fund_param.DiffJudgeAssetWgtRequirement} fund_selection_min_score {fund_selection_min_score} c.fund_judge_ranking {c.fund_judge_ranking}')
             index_fund_cache.append(c)
-
         # self.fund_param.DiffJudgeLambda = 0
         trigger = 0
         trigger += TradeTrigger.IndexRebalance if index_rebalance_max_diff > self.fund_param.JudgeIndexDiff else 0
@@ -426,7 +427,7 @@ class FundTrader(AssetTrader):
                                                   _fund_rebalance_min_name,
                                                   self.fund_param.JudgeFundRebalance)
         
-        
+        #print(f'trigger_detail {trigger_detail}')
         if trigger > 0:
             if self.trade_interval_allow(dt):
                 #print(f'judge allow {dt} (trigger){TradeTrigger.parse(trigger)} (Fs){fund_selection_min_score}[{_fund_selection_min_name}]#{self.fund_param.JudgeFundSelection} (Fr){fund_rebalance_min_score}/[{_fund_rebalance_min_name}]#{self.fund_param.JudgeFundRebalance} (Ir){index_rebalance_max_diff}/[{_index_rebalance_max_diff_name}]#{self.fund_param.JudgeIndexDiff}')
