@@ -33,6 +33,7 @@ class SeriesStatUnit:
     y_2020_ret: float                   # 2020年收益
     last_year_ret: float                # 去年收益
     recent_y1_ret: float                # 近一年收益
+    recent_y2_ret: float                # 近二年收益
     recent_y3_ret: float                # 近三年收益
     recent_y5_ret: float                # 近五年收益
     mdd: float                          # 最大回撤
@@ -60,6 +61,27 @@ class SeriesStatUnit:
     nav_type: str                       # 净值类型
     w1_end_date: datetime.date          # 近一周结束时间
     w1_begin_date: datetime.date        # 近一周开始时间
+    recent_1w_annual_ret: float         # 近一周年化收益
+    recent_1w_mdd: float                # 近一周最大回撤
+    recent_1m_annual_ret: float         # 近一月年化收益
+    recent_1m_mdd: float                # 近一月最大回撤
+    recent_3m_annual_ret: float         # 近三月年化收益
+    recent_3m_mdd: float                # 近三月最大回撤
+    recent_6m_annual_ret: float         # 近六月年化收益
+    recent_6m_mdd: float                # 近六月最大回撤
+    recent_1y_annual_ret: float         # 近一年年化收益
+    recent_1y_mdd: float                # 近一年最大回撤
+    recent_2y_annual_ret: float         # 近两年年化收益
+    recent_2y_mdd: float                # 近两年最大回撤
+    recent_3y_annual_ret: float         # 近三年年化收益
+    recent_3y_mdd: float                # 近三年最大回撤
+    recent_4y_annual_ret: float         # 近四年年化收益
+    recent_4y_mdd: float                # 近四年最大回撤
+    recent_5y_annual_ret: float         # 近五年年化收益
+    recent_5y_mdd: float                # 近五年最大回撤
+    y_last_ret_annual: float            # 本自然年年化收益
+    y_last_mdd: float                   # 本自然年最大回撤
+
 
 @dataclasses.dataclass
 class BenchmarkSeiesStatUnit(SeriesStatUnit):
@@ -90,6 +112,7 @@ class BenchmarkSeiesStatUnit(SeriesStatUnit):
     skew: float                     # 偏度
     kurtosis: float                 # 峰度
     total_relative_ret: float       # 相对全部收益
+    asset_to_bmk_mdd:float          # 资产对基准回撤比例
 
 @dataclasses.dataclass
 class RetStatUnit:
@@ -100,6 +123,7 @@ class RetStatUnit:
     recent_3m_ret: float                # 最近三月收益 未年化
     recent_6m_ret: float                # 最近半年收益 未年化
     recent_1y_ret: float                # 最近一年收益 未年化
+    recent_2y_ret: float                # 最近二年收益 未年化
     recent_3y_ret: float                # 最近三年收益 未年化
     recent_5y_ret: float                # 最近五年收益 未年化
     history_ret: float                  # 成立以来收益 未年化
@@ -169,6 +193,7 @@ class Calculator:
             recent_3m_ret=res['recent_3m_ret'],
             recent_6m_ret=res['recent_6m_ret'],
             recent_y1_ret=res['recent_1y_ret'],
+            recent_y2_ret=res['recent_2y_ret'],
             recent_y3_ret=res['recent_3y_ret'],
             recent_y5_ret=res['recent_5y_ret'],
             worst_3m_ret=res['worst_3m_ret'],
@@ -197,6 +222,26 @@ class Calculator:
             nav_type=res['nav_type'],
             w1_begin_date=res['w1_begin_date'],
             w1_end_date=res['w1_end_date'],
+            recent_1w_annual_ret=res['recent_1w_annual_ret'],
+            recent_1w_mdd=res['recent_1w_mdd'],
+            recent_1m_annual_ret=res['recent_1m_annual_ret'],
+            recent_1m_mdd=res['recent_1m_mdd'],
+            recent_3m_annual_ret=res['recent_3m_annual_ret'],
+            recent_3m_mdd=res['recent_3m_mdd'],
+            recent_6m_annual_ret=res['recent_6m_annual_ret'],
+            recent_6m_mdd=res['recent_6m_mdd'],
+            recent_1y_annual_ret=res['recent_1y_annual_ret'],
+            recent_1y_mdd=res['recent_1y_mdd'],
+            recent_2y_annual_ret=res['recent_2y_annual_ret'],
+            recent_2y_mdd=res['recent_2y_mdd'],
+            recent_3y_annual_ret=res['recent_3y_annual_ret'],
+            recent_3y_mdd=res['recent_3y_mdd'],
+            recent_4y_annual_ret=res['recent_4y_annual_ret'],
+            recent_4y_mdd=res['recent_4y_mdd'],
+            recent_5y_annual_ret=res['recent_5y_annual_ret'],
+            recent_5y_mdd=res['recent_5y_mdd'],
+            y_last_ret_annual=res['y_last_ret_annual'],
+            y_last_mdd=res['y_last_mdd'],
         )
 
     @staticmethod
@@ -298,6 +343,28 @@ class Calculator:
             nav_type=res['nav_type'],
             w1_begin_date=res['w1_begin_date'],
             w1_end_date=res['w1_end_date'],
+            recent_y2_ret=res['recent_2y_ret'],
+            recent_1w_annual_ret=res['recent_1w_annual_ret'],
+            recent_1w_mdd=res['recent_1w_mdd'],
+            recent_1m_annual_ret=res['recent_1m_annual_ret'],
+            recent_1m_mdd=res['recent_1m_mdd'],
+            recent_3m_annual_ret=res['recent_3m_annual_ret'],
+            recent_3m_mdd=res['recent_3m_mdd'],
+            recent_6m_annual_ret=res['recent_6m_annual_ret'],
+            recent_6m_mdd=res['recent_6m_mdd'],
+            recent_1y_annual_ret=res['recent_1y_annual_ret'],
+            recent_1y_mdd=res['recent_1y_mdd'],
+            recent_2y_annual_ret=res['recent_2y_annual_ret'],
+            recent_2y_mdd=res['recent_2y_mdd'],
+            recent_3y_annual_ret=res['recent_3y_annual_ret'],
+            recent_3y_mdd=res['recent_3y_mdd'],
+            recent_4y_annual_ret=res['recent_4y_annual_ret'],
+            recent_4y_mdd=res['recent_4y_mdd'],
+            recent_5y_annual_ret=res['recent_5y_annual_ret'],
+            recent_5y_mdd=res['recent_5y_mdd'],
+            y_last_ret_annual=res['y_last_ret_annual'],
+            y_last_mdd=res['y_last_mdd'],
+            asset_to_bmk_mdd=res['asset_to_bmk_mdd'], 
         )
 
     @staticmethod
@@ -312,6 +379,7 @@ class Calculator:
             recent_3m_ret=res['recent_3m_ret'],
             recent_6m_ret=res['recent_6m_ret'],
             recent_1y_ret=res['recent_1y_ret'],
+            recent_2y_ret=res['recent_2y_ret'],
             recent_3y_ret=res['recent_3y_ret'],
             recent_5y_ret=res['recent_5y_ret'],
             history_ret=res['history_ret'],
